From 915c73083cf1fa8d173937e3a2d85a56a5884055 Mon Sep 17 00:00:00 2001
From: Tim Daly <daly@axiom-developer.org>
Date: Thu, 8 Jan 2015 17:34:35 -0500
Subject: Makefile fix false error message on TESTSET=notests

The default make sets TESTSET=notests which does not run the
test suite but the last step of the build tried to find
failing test cases. But since there were no test cases it
threw an error. This is fixed.
---
 Makefile.pamphlet              |   63 ++++++++++++++++++++++++++-------------
 changelog                      |    2 +
 patch                          |    8 ++++-
 src/axiom-website/patches.html |    2 +
 4 files changed, 53 insertions(+), 22 deletions(-)

diff --git a/Makefile.pamphlet b/Makefile.pamphlet
index 014a659..3250617 100644
--- a/Makefile.pamphlet
+++ b/Makefile.pamphlet
@@ -937,7 +937,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.FreeBSD called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -969,7 +970,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.windows called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -988,7 +990,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.slackware called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -1009,7 +1012,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -1030,7 +1034,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.mandriva called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -1051,7 +1056,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -1072,7 +1078,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -1093,7 +1100,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -1114,7 +1122,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -1135,7 +1144,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -1156,7 +1166,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -1177,7 +1188,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -1200,7 +1212,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -1221,7 +1234,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -1245,7 +1259,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.macosxppc called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -1267,7 +1282,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.fedora called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -1306,7 +1322,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -1347,7 +1364,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -1370,7 +1388,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -1393,7 +1412,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
@@ -1434,7 +1454,8 @@ all: srcsetup lspdir srcdir
 	@echo 45 Makefile.linux called
 	@echo 46 Environment : ${ENV} 
 	@echo 47 finished system build on `date` | tee >lastBuildDate
-	@- grep "result FAILED" int/input/*.regress
+	@- if [ "${TESTSET}" != "notests" ] ; \
+            then  grep "result FAILED" int/input/*.regress ; fi
 
 \getchunk{literate commands}
 \getchunk{srcsetup}
diff --git a/changelog b/changelog
index 6789363..f9692d2 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,5 @@
+20150108 tpd src/axiom-website/patches.html 20150108.02.tpd.patch
+20150108 tpd Makefile fix false error message on TESTSET=notests
 20150108 tpd src/axiom-website/patches.html 20150108.01.tpd.patch
 20150118 tpd books/bookvol10.2 remove |function| macro
 20150107 tpd src/axiom-website/patches.html 20150107.08.tpd.patch
diff --git a/patch b/patch
index 6d8b32d..41071b0 100644
--- a/patch
+++ b/patch
@@ -1 +1,7 @@
-books/bookvol10.2 remove |function| macro
+Makefile fix false error message on TESTSET=notests
+
+The default make sets TESTSET=notests which does not run the
+test suite but the last step of the build tried to find 
+failing test cases. But since there were no test cases it
+threw an error. This is fixed.
+
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index dbaee8c..8a97417 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -4940,6 +4940,8 @@ src/input/* review and improve test cases<br/>
 projects: January 7th 2015 update<br/>
 <a href="patches/20150108.01.tpd.patch">20150108.01.tpd.patch</a>
 books/bookvol10.2 remove |function| macro<br/>
+<a href="patches/20150108.02.tpd.patch">20150108.02.tpd.patch</a>
+Makefile fix false error message on TESTSET=notests<br/>
  </body>
 </html>
 
-- 
1.7.5.4

